fs_search: FactSet Filesystem Search

Description Usage Arguments Value See Also Examples

View source: R/search.R

Description

This function makes it easy to search your FactSet filesystem. It returns a tibble with the accounts, directories, or documents in the specified directory.

Usage

1
fs_search(con, dir, type = c("pa", "spar", "dir", "accounts"))

Arguments

con

A FactSet connection object.

dir

A directory in the FactSet filesystem associated with your serial number.

type

The type of item you want to search for. Right now the options include accounts, directories, PA documents, or SPAR documents.

Value

A tibble containing the accounts, documents, or directories within the specified directory.

See Also

See fs_auth for authentication instructions.

Examples

1
fs_pa_docs <- fs_search(con, dir, type = "pa")

chris-lundberg/factsetr documentation built on Feb. 27, 2020, 8:59 a.m.