Description Usage Arguments Value See Also Examples
This function makes it easy to search your FactSet filesystem. It returns a tibble with the accounts, directories, or documents in the specified directory.
1 |
con |
A FactSet connection object. |
dir |
A directory in the FactSet filesystem associated with your serial number. |
type |
The type of item you want to search for. Right now the options include accounts, directories, PA documents, or SPAR documents. |
A tibble containing the accounts, documents, or directories within the specified directory.
See fs_auth for authentication instructions.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.